from setuptools import setup

name = "types-python-xlib"
description = "Typing stubs for python-xlib"
long_description = '''
## Typing stubs for python-xlib

This is a PEP 561 type stub package for the `python-xlib` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `python-xlib`. The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/python-xlib. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit `07f587dc70f75b3137e279777fbe289416f4adf2`.
'''.lstrip()

setup(name=name,
      version="0.33.0.0",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/python-xlib.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=['types-Pillow'],
      packages=['Xlib-stubs'],
      package_data={'Xlib-stubs': ['X.pyi', 'XK.pyi', 'Xatom.pyi', 'Xcursorfont.pyi', 'Xutil.pyi', '__init__.pyi', '_typing.pyi', 'display.pyi', 'error.pyi', 'ext/__init__.pyi', 'ext/composite.pyi', 'ext/damage.pyi', 'ext/dpms.pyi', 'ext/ge.pyi', 'ext/nvcontrol.pyi', 'ext/randr.pyi', 'ext/record.pyi', 'ext/res.pyi', 'ext/screensaver.pyi', 'ext/security.pyi', 'ext/shape.pyi', 'ext/xfixes.pyi', 'ext/xinerama.pyi', 'ext/xinput.pyi', 'ext/xtest.pyi', 'keysymdef/__init__.pyi', 'keysymdef/apl.pyi', 'keysymdef/arabic.pyi', 'keysymdef/cyrillic.pyi', 'keysymdef/greek.pyi', 'keysymdef/hebrew.pyi', 'keysymdef/katakana.pyi', 'keysymdef/korean.pyi', 'keysymdef/latin1.pyi', 'keysymdef/latin2.pyi', 'keysymdef/latin3.pyi', 'keysymdef/latin4.pyi', 'keysymdef/miscellany.pyi', 'keysymdef/publishing.pyi', 'keysymdef/special.pyi', 'keysymdef/technical.pyi', 'keysymdef/thai.pyi', 'keysymdef/xf86.pyi', 'keysymdef/xk3270.pyi', 'keysymdef/xkb.pyi', 'protocol/__init__.pyi', 'protocol/display.pyi', 'protocol/event.pyi', 'protocol/request.pyi', 'protocol/rq.pyi', 'protocol/structs.pyi', 'rdb.pyi', 'support/__init__.pyi', 'support/connect.pyi', 'support/lock.pyi', 'support/unix_connect.pyi', 'support/vms_connect.pyi', 'threaded.pyi', 'xauth.pyi', 'xobject/__init__.pyi', 'xobject/colormap.pyi', 'xobject/cursor.pyi', 'xobject/drawable.pyi', 'xobject/fontable.pyi', 'xobject/icccm.pyi', 'xobject/resource.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)



XK_kra: int
XK_kappa: int
XK_Rcedilla: int
XK_Itilde: int
XK_Lcedilla: int
XK_Emacron: int
XK_Gcedilla: int
XK_Tslash: int
XK_rcedilla: int
XK_itilde: int
XK_lcedilla: int
XK_emacron: int
XK_gcedilla: int
XK_tslash: int
XK_ENG: int
XK_eng: int
XK_Amacron: int
XK_Iogonek: int
XK_Eabovedot: int
XK_Imacron: int
XK_Ncedilla: int
XK_Omacron: int
XK_Kcedilla: int
XK_Uogonek: int
XK_Utilde: int
XK_Umacron: int
XK_amacron: int
XK_iogonek: int
XK_eabovedot: int
XK_imacron: int
XK_ncedilla: int
XK_omacron: int
XK_kcedilla: int
XK_uogonek: int
XK_utilde: int
XK_umacron: int



XK_3270_Duplicate: int
XK_3270_FieldMark: int
XK_3270_Right2: int
XK_3270_Left2: int
XK_3270_BackTab: int
XK_3270_EraseEOF: int
XK_3270_EraseInput: int
XK_3270_Reset: int
XK_3270_Quit: int
XK_3270_PA1: int
XK_3270_PA2: int
XK_3270_PA3: int
XK_3270_Test: int
XK_3270_Attn: int
XK_3270_CursorBlink: int
XK_3270_AltCursor: int
XK_3270_KeyClick: int
XK_3270_Jump: int
XK_3270_Ident: int
XK_3270_Rule: int
XK_3270_Copy: int
XK_3270_Play: int
XK_3270_Setup: int
XK_3270_Record: int
XK_3270_ChangeScreen: int
XK_3270_DeleteWord: int
XK_3270_ExSelect: int
XK_3270_CursorSelect: int
XK_3270_PrintScreen: int
XK_3270_Enter: int



XK_XF86_ModeLock: int
XK_XF86_MonBrightnessUp: int
XK_XF86_MonBrightnessDown: int
XK_XF86_KbdLightOnOff: int
XK_XF86_KbdBrightnessUp: int
XK_XF86_KbdBrightnessDown: int
XK_XF86_MonBrightnessCycle: int
XK_XF86_Standby: int
XK_XF86_AudioLowerVolume: int
XK_XF86_AudioMute: int
XK_XF86_AudioRaiseVolume: int
XK_XF86_AudioPlay: int
XK_XF86_AudioStop: int
XK_XF86_AudioPrev: int
XK_XF86_AudioNext: int
XK_XF86_HomePage: int
XK_XF86_Mail: int
XK_XF86_Start: int
XK_XF86_Search: int
XK_XF86_AudioRecord: int
XK_XF86_Calculator: int
XK_XF86_Memo: int
XK_XF86_ToDoList: int
XK_XF86_Calendar: int
XK_XF86_PowerDown: int
XK_XF86_ContrastAdjust: int
XK_XF86_RockerUp: int
XK_XF86_RockerDown: int
XK_XF86_RockerEnter: int
XK_XF86_Back: int
XK_XF86_Forward: int
XK_XF86_Stop: int
XK_XF86_Refresh: int
XK_XF86_PowerOff: int
XK_XF86_WakeUp: int
XK_XF86_Eject: int
XK_XF86_ScreenSaver: int
XK_XF86_WWW: int
XK_XF86_Sleep: int
XK_XF86_Favorites: int
XK_XF86_AudioPause: int
XK_XF86_AudioMedia: int
XK_XF86_MyComputer: int
XK_XF86_VendorHome: int
XK_XF86_LightBulb: int
XK_XF86_Shop: int
XK_XF86_History: int
XK_XF86_OpenURL: int
XK_XF86_AddFavorite: int
XK_XF86_HotLinks: int
XK_XF86_BrightnessAdjust: int
XK_XF86_Finance: int
XK_XF86_Community: int
XK_XF86_AudioRewind: int
XK_XF86_XF86BackForward: int
XK_XF86_Launch0: int
XK_XF86_Launch1: int
XK_XF86_Launch2: int
XK_XF86_Launch3: int
XK_XF86_Launch4: int
XK_XF86_Launch5: int
XK_XF86_Launch6: int
XK_XF86_Launch7: int
XK_XF86_Launch8: int
XK_XF86_Launch9: int
XK_XF86_LaunchA: int
XK_XF86_LaunchB: int
XK_XF86_LaunchC: int
XK_XF86_LaunchD: int
XK_XF86_LaunchE: int
XK_XF86_LaunchF: int
XK_XF86_ApplicationLeft: int
XK_XF86_ApplicationRight: int
XK_XF86_Book: int
XK_XF86_CD: int
XK_XF86_Calculater: int
XK_XF86_Clear: int
XK_XF86_Close: int
XK_XF86_Copy: int
XK_XF86_Cut: int
XK_XF86_Display: int
XK_XF86_DOS: int
XK_XF86_Documents: int
XK_XF86_Excel: int
XK_XF86_Explorer: int
XK_XF86_Game: int
XK_XF86_Go: int
XK_XF86_iTouch: int
XK_XF86_LogOff: int
XK_XF86_Market: int
XK_XF86_Meeting: int
XK_XF86_MenuKB: int
XK_XF86_MenuPB: int
XK_XF86_MySites: int
XK_XF86_New: int
XK_XF86_News: int
XK_XF86_OfficeHome: int
XK_XF86_Open: int
XK_XF86_Option: int
XK_XF86_Paste: int
XK_XF86_Phone: int
XK_XF86_Q: int
XK_XF86_Reply: int
XK_XF86_Reload: int
XK_XF86_RotateWindows: int
XK_XF86_RotationPB: int
XK_XF86_RotationKB: int
XK_XF86_Save: int
XK_XF86_ScrollUp: int
XK_XF86_ScrollDown: int
XK_XF86_ScrollClick: int
XK_XF86_Send: int
XK_XF86_Spell: int
XK_XF86_SplitScreen: int
XK_XF86_Support: int
XK_XF86_TaskPane: int
XK_XF86_Terminal: int
XK_XF86_Tools: int
XK_XF86_Travel: int
XK_XF86_UserPB: int
XK_XF86_User1KB: int
XK_XF86_User2KB: int
XK_XF86_Video: int
XK_XF86_WheelButton: int
XK_XF86_Word: int
XK_XF86_Xfer: int
XK_XF86_ZoomIn: int
XK_XF86_ZoomOut: int
XK_XF86_Away: int
XK_XF86_Messenger: int
XK_XF86_WebCam: int
XK_XF86_MailForward: int
XK_XF86_Pictures: int
XK_XF86_Music: int
XK_XF86_Battery: int
XK_XF86_Bluetooth: int
XK_XF86_WLAN: int
XK_XF86_UWB: int
XK_XF86_AudioForward: int
XK_XF86_AudioRepeat: int
XK_XF86_AudioRandomPlay: int
XK_XF86_Subtitle: int
XK_XF86_AudioCycleTrack: int
XK_XF86_CycleAngle: int
XK_XF86_FrameBack: int
XK_XF86_FrameForward: int
XK_XF86_Time: int
XK_XF86_Select: int
XK_XF86_View: int
XK_XF86_TopMenu: int
XK_XF86_Red: int
XK_XF86_Green: int
XK_XF86_Yellow: int
XK_XF86_Blue: int
XK_XF86_Suspend: int
XK_XF86_Hibernate: int
XK_XF86_TouchpadToggle: int
XK_XF86_TouchpadOn: int
XK_XF86_TouchpadOff: int
XK_XF86_AudioMicMute: int
XK_XF86_Keyboard: int
XK_XF86_WWAN: int
XK_XF86_RFKill: int
XK_XF86_AudioPreset: int
XK_XF86_RotationLockToggle: int
XK_XF86_FullScreen: int
XK_XF86_Switch_VT_1: int
XK_XF86_Switch_VT_2: int
XK_XF86_Switch_VT_3: int
XK_XF86_Switch_VT_4: int
XK_XF86_Switch_VT_5: int
XK_XF86_Switch_VT_6: int
XK_XF86_Switch_VT_7: int
XK_XF86_Switch_VT_8: int
XK_XF86_Switch_VT_9: int
XK_XF86_Switch_VT_10: int
XK_XF86_Switch_VT_11: int
XK_XF86_Switch_VT_12: int
XK_XF86_Ungrab: int
XK_XF86_ClearGrab: int
XK_XF86_Next_VMode: int
XK_XF86_Prev_VMode: int
XK_XF86_LogWindowTree: int
XK_XF86_LogGrabInfo: int



XK_hebrew_doublelowline: int
XK_hebrew_aleph: int
XK_hebrew_bet: int
XK_hebrew_beth: int
XK_hebrew_gimel: int
XK_hebrew_gimmel: int
XK_hebrew_dalet: int
XK_hebrew_daleth: int
XK_hebrew_he: int
XK_hebrew_waw: int
XK_hebrew_zain: int
XK_hebrew_zayin: int
XK_hebrew_chet: int
XK_hebrew_het: int
XK_hebrew_tet: int
XK_hebrew_teth: int
XK_hebrew_yod: int
XK_hebrew_finalkaph: int
XK_hebrew_kaph: int
XK_hebrew_lamed: int
XK_hebrew_finalmem: int
XK_hebrew_mem: int
XK_hebrew_finalnun: int
XK_hebrew_nun: int
XK_hebrew_samech: int
XK_hebrew_samekh: int
XK_hebrew_ayin: int
XK_hebrew_finalpe: int
XK_hebrew_pe: int
XK_hebrew_finalzade: int
XK_hebrew_finalzadi: int
XK_hebrew_zade: int
XK_hebrew_zadi: int
XK_hebrew_qoph: int
XK_hebrew_kuf: int
XK_hebrew_resh: int
XK_hebrew_shin: int
XK_hebrew_taw: int
XK_hebrew_taf: int
XK_Hebrew_switch: int



XK_space: int
XK_exclam: int
XK_quotedbl: int
XK_numbersign: int
XK_dollar: int
XK_percent: int
XK_ampersand: int
XK_apostrophe: int
XK_quoteright: int
XK_parenleft: int
XK_parenright: int
XK_asterisk: int
XK_plus: int
XK_comma: int
XK_minus: int
XK_period: int
XK_slash: int
XK_0: int
XK_1: int
XK_2: int
XK_3: int
XK_4: int
XK_5: int
XK_6: int
XK_7: int
XK_8: int
XK_9: int
XK_colon: int
XK_semicolon: int
XK_less: int
XK_equal: int
XK_greater: int
XK_question: int
XK_at: int
XK_A: int
XK_B: int
XK_C: int
XK_D: int
XK_E: int
XK_F: int
XK_G: int
XK_H: int
XK_I: int
XK_J: int
XK_K: int
XK_L: int
XK_M: int
XK_N: int
XK_O: int
XK_P: int
XK_Q: int
XK_R: int
XK_S: int
XK_T: int
XK_U: int
XK_V: int
XK_W: int
XK_X: int
XK_Y: int
XK_Z: int
XK_bracketleft: int
XK_backslash: int
XK_bracketright: int
XK_asciicircum: int
XK_underscore: int
XK_grave: int
XK_quoteleft: int
XK_a: int
XK_b: int
XK_c: int
XK_d: int
XK_e: int
XK_f: int
XK_g: int
XK_h: int
XK_i: int
XK_j: int
XK_k: int
XK_l: int
XK_m: int
XK_n: int
XK_o: int
XK_p: int
XK_q: int
XK_r: int
XK_s: int
XK_t: int
XK_u: int
XK_v: int
XK_w: int
XK_x: int
XK_y: int
XK_z: int
XK_braceleft: int
XK_bar: int
XK_braceright: int
XK_asciitilde: int
XK_nobreakspace: int
XK_exclamdown: int
XK_cent: int
XK_sterling: int
XK_currency: int
XK_yen: int
XK_brokenbar: int
XK_section: int
XK_diaeresis: int
XK_copyright: int
XK_ordfeminine: int
XK_guillemotleft: int
XK_notsign: int
XK_hyphen: int
XK_registered: int
XK_macron: int
XK_degree: int
XK_plusminus: int
XK_twosuperior: int
XK_threesuperior: int
XK_acute: int
XK_mu: int
XK_paragraph: int
XK_periodcentered: int
XK_cedilla: int
XK_onesuperior: int
XK_masculine: int
XK_guillemotright: int
XK_onequarter: int
XK_onehalf: int
XK_threequarters: int
XK_questiondown: int
XK_Agrave: int
XK_Aacute: int
XK_Acircumflex: int
XK_Atilde: int
XK_Adiaeresis: int
XK_Aring: int
XK_AE: int
XK_Ccedilla: int
XK_Egrave: int
XK_Eacute: int
XK_Ecircumflex: int
XK_Ediaeresis: int
XK_Igrave: int
XK_Iacute: int
XK_Icircumflex: int
XK_Idiaeresis: int
XK_ETH: int
XK_Eth: int
XK_Ntilde: int
XK_Ograve: int
XK_Oacute: int
XK_Ocircumflex: int
XK_Otilde: int
XK_Odiaeresis: int
XK_multiply: int
XK_Ooblique: int
XK_Ugrave: int
XK_Uacute: int
XK_Ucircumflex: int
XK_Udiaeresis: int
XK_Yacute: int
XK_THORN: int
XK_Thorn: int
XK_ssharp: int
XK_agrave: int
XK_aacute: int
XK_acircumflex: int
XK_atilde: int
XK_adiaeresis: int
XK_aring: int
XK_ae: int
XK_ccedilla: int
XK_egrave: int
XK_eacute: int
XK_ecircumflex: int
XK_ediaeresis: int
XK_igrave: int
XK_iacute: int
XK_icircumflex: int
XK_idiaeresis: int
XK_eth: int
XK_ntilde: int
XK_ograve: int
XK_oacute: int
XK_ocircumflex: int
XK_otilde: int
XK_odiaeresis: int
XK_division: int
XK_oslash: int
XK_ugrave: int
XK_uacute: int
XK_ucircumflex: int
XK_udiaeresis: int
XK_yacute: int
XK_thorn: int
XK_ydiaeresis: int



XK_Arabic_comma: int
XK_Arabic_semicolon: int
XK_Arabic_question_mark: int
XK_Arabic_hamza: int
XK_Arabic_maddaonalef: int
XK_Arabic_hamzaonalef: int
XK_Arabic_hamzaonwaw: int
XK_Arabic_hamzaunderalef: int
XK_Arabic_hamzaonyeh: int
XK_Arabic_alef: int
XK_Arabic_beh: int
XK_Arabic_tehmarbuta: int
XK_Arabic_teh: int
XK_Arabic_theh: int
XK_Arabic_jeem: int
XK_Arabic_hah: int
XK_Arabic_khah: int
XK_Arabic_dal: int
XK_Arabic_thal: int
XK_Arabic_ra: int
XK_Arabic_zain: int
XK_Arabic_seen: int
XK_Arabic_sheen: int
XK_Arabic_sad: int
XK_Arabic_dad: int
XK_Arabic_tah: int
XK_Arabic_zah: int
XK_Arabic_ain: int
XK_Arabic_ghain: int
XK_Arabic_tatweel: int
XK_Arabic_feh: int
XK_Arabic_qaf: int
XK_Arabic_kaf: int
XK_Arabic_lam: int
XK_Arabic_meem: int
XK_Arabic_noon: int
XK_Arabic_ha: int
XK_Arabic_heh: int
XK_Arabic_waw: int
XK_Arabic_alefmaksura: int
XK_Arabic_yeh: int
XK_Arabic_fathatan: int
XK_Arabic_dammatan: int
XK_Arabic_kasratan: int
XK_Arabic_fatha: int
XK_Arabic_damma: int
XK_Arabic_kasra: int
XK_Arabic_shadda: int
XK_Arabic_sukun: int
XK_Arabic_switch: int
